@@ -69,6 +69,8 @@ def calculate_maxi_min_rjl(data):
         max_r = max(lst)
         min_r = min(lst)
         if max_r == min_r:
+            if '＜容积率' in data  or  '≤容积率' in data :
+                data=f'大于{min_r}'
             if '小于' in data or 'FAR' in data or '小于等于' in data or '小于或等于' in data or '不大于' in data or '等于' in data or '不得大于' in data or '不高于' in data or '低于' in data or '不超过' in data or '以下' in data or '以内' in data or '＜' in data or '<' in data or '≦' in data or '≤' in data or '<=' in data or '＜＝' in data or '≯' in data or '上限' in data:
                 min_rongjilv = ''
                 max_rongjilv = max_r
@@ -294,5 +296,5 @@ def read_csv():
 
 if __name__ == '__main__':
     # data=['20%＜绿地率','绿地率≥25%','0.9> 小于1.0','1.0<容积率＜3.0，容积率≯2.0, 容积率>4.0','居住用地  ≤2.6；  商业用地  ≤2.5', '小于1.6、S2;小于1.8大于1.0', '小于1.8大于1.0、S2;小于1.6', 'S1：不大于1.8不小于1.0、S2;不大于1.6']
-    data=['居住1.0 商业≤0.6']
+    data=['0.7≤容积率']
     print(calculate_maxi_min_rjl(data[0]))
